==> zither-1.1.16.tar.gz: zither_prj/zither/global_data_list.c <==

#include<stdio.h>
#include<stdlib.h>
#include<sys/types.h>
#include<unistd.h>
#include<sys/socket.h>
#include<sys/wait.h>
#include<string.h>
#include<netinet/in.h>
#include<arpa/inet.h>
#include<pthread.h>

#include"zither.h"
#include<almemsys/almemsys.h>
#include"jpreturn.h"


extern global_data_t gd;



/*--------------- GLOBAL DATA LIST(FOR DEBUG) ---------------  */
int global_data_list(private_data_t * pd)
{
int ret;
ret = 0;

char * putdata = (char *)calloc(IP_LEN, sizeof(char));

if(0 == self_memcmp(pd->rec.user, "administrator")){
   putdata = safe_sprintf(putdata, BUF_MAX,
   "200 KO\n%s%s\n%s%d\n%s%d\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%d\n%s%d\n%s%d\n%s%d\n%s%s\n",
     "gd.ms.ip_addr:       ",gd.ms.ip_addr,
     "gd.ms.port:          ",gd.ms.port,
     "gd.ms.max_count:     ",gd.ms.max_count,
     "gd.fp.lock_path:     ",gd.fp.lock_path,
     "gd.fp.file_conf:     ",gd.fp.file_conf,
     "gd.fp.neg_conf:      ",gd.fp.neg_conf,
     "gd.md.ch_MailFrom:   ",gd.md.ch_MailFrom,
     "gd.md.ch_MailRcptTo: ",gd.md.ch_MailRcptTo,
     "gd.md.ch_MailServ:   ",gd.md.ch_MailServ,
     "gd.md.ch_MailCc:     ",gd.md.ch_MailCc,
     "gd.bs.life_int:      ",gd.bs.life_int,
     "gd.bs.life_los:      ",gd.bs.life_los,
     "gd.exid.uid:         ",gd.exid.uid,
     "gd.md.in_mailonoff:  ",gd.md.in_mailonoff,
     "CL_VAR:              ",CL_VAR);

   swap_mem(putdata, '\n', ';', (int)strlen(putdata));
   putdata = safe_strncat(putdata, "\n", BUF_MAX);

   ret = socket_send(gd.ms.sk[pd->rec.fdno], putdata, (pd->life.life_int + pd->life.life_los + 15));

   #ifdef LOG_OUT
   pthread_mutex_lock(&con_mutex);
   log_out(gd.fp.con_fd, pd->rec.user, pd->rec.com,
    pd->rec.data, "check global data struct.", gd.ms.inip_addr[pd->rec.fdno]);
   pthread_mutex_unlock(&con_mutex);
   #endif
   }
else{
   ret = socket_send(gd.ms.sk[pd->rec.fdno], "500 NG\n", (pd->life.life_int + pd->life.life_los + 15));

   #ifdef LOG_OUT
   pthread_mutex_lock(&con_mutex);
   log_out(gd.fp.con_fd, pd->rec.user, pd->rec.com,
    pd->rec.data, "500 NG", gd.ms.inip_addr[pd->rec.fdno]);
   pthread_mutex_unlock(&con_mutex);
   #endif
   } 

free(putdata);
return ret ;
}

==> zither-1.1.19.tar.gz: zither_prj/zither/global_data_list.c <==

#include<stdio.h>
#include<stdlib.h>
#include<sys/types.h>
#include<unistd.h>
#include<sys/socket.h>
#include<sys/wait.h>
#include<string.h>
#include<netinet/in.h>
#include<arpa/inet.h>
#include<pthread.h>

#include"zither.h"
#include<almemsys/almemsys.h>
#include"jpreturn.h"


extern global_data_t gd;



/*--------------- GLOBAL DATA LIST(FOR DEBUG) ---------------  */
int global_data_list(private_data_t * pd)
{
int ret;
ret = 0;

char * putdata = (char *)calloc(IP_LEN, sizeof(char));

if(0 == self_memcmp(pd->rec.user, "administrator")){
   putdata = safe_sprintf(putdata, BUF_MAX,
   "200 KO\n%s%s\n%s%d\n%s%d\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%d\n%s%d\n%s%d\n%s%d\n%s%s\n",
     "gd.ms.ip_addr:       ",gd.ms.ip_addr,
     "gd.ms.port:          ",gd.ms.port,
     "gd.ms.max_count:     ",gd.ms.max_count,
     "gd.fp.lock_path:     ",gd.fp.lock_path,
     "gd.fp.file_conf:     ",gd.fp.file_conf,
     "gd.fp.neg_conf:      ",gd.fp.neg_conf,
     "gd.md.ch_MailFrom:   ",gd.md.ch_MailFrom,
     "gd.md.ch_MailRcptTo: ",gd.md.ch_MailRcptTo,
     "gd.md.ch_MailServ:   ",gd.md.ch_MailServ,
     "gd.md.ch_MailCc:     ",gd.md.ch_MailCc,
     "gd.bs.life_int:      ",gd.bs.life_int,
     "gd.bs.life_los:      ",gd.bs.life_los,
     "gd.exid.uid:         ",gd.exid.uid,
     "gd.md.in_mailonoff:  ",gd.md.in_mailonoff,
     "CL_VAR:              ",CL_VAR);

   swap_mem(putdata, '\n', ';');
   putdata = safe_strncat(putdata, "\n", BUF_MAX);

   ret = socket_send(gd.ms.sk[pd->rec.fdno], putdata, (pd->life.life_int + pd->life.life_los + 15));

   #ifdef LOG_OUT
   pthread_mutex_lock(&con_mutex);
   log_out(gd.fp.con_fd, pd->rec.user, pd->rec.com,
    pd->rec.data, "check global data struct.", gd.ms.inip_addr[pd->rec.fdno]);
   pthread_mutex_unlock(&con_mutex);
   #endif
   }
else{
   ret = socket_send(gd.ms.sk[pd->rec.fdno], "500 NG\n", (pd->life.life_int + pd->life.life_los + 15));

   #ifdef LOG_OUT
   pthread_mutex_lock(&con_mutex);
   log_out(gd.fp.con_fd, pd->rec.user, pd->rec.com,
    pd->rec.data, "500 NG", gd.ms.inip_addr[pd->rec.fdno]);
   pthread_mutex_unlock(&con_mutex);
   #endif
   } 

free(putdata);
return ret ;
}
